# spotidry

This is a real dry & boring command line interface client for Spotify.

My motivation for this project is to have a simple client that display the currently-playing track, along with it's Liked status.
I also want to be able to save the currently-playing song to my Liked Tracks.
